@@ -26,8 +26,8 @@
 #include <tqheader.h>
 #include <tqclipboard.h>
 #include <tqpainter.h>
-#include <klocale.h>
-#include <kglobalsettings.h>
+#include <tdelocale.h>
+#include <tdeglobalsettings.h>
 #include <tqscrollbar.h>
 #include <tqcursor.h>
 #include <tqstyle.h>
@@ -135,7 +135,7 @@ void DolphinDetailsView::insertItem(KFileItem* fileItem)
 
     TQDir::SortSpec spec = KFileView::sorting();
     if (spec & TQDir::Time) {
-        item->setKey(sortingKey(fileItem->time(KIO::UDS_MODIFICATION_TIME),
+        item->setKey(sortingKey(fileItem->time(TDEIO::UDS_MODIFICATION_TIME),
                                 fileItem->isDir(),
                                 spec));
     }
@@ -179,8 +179,8 @@ void DolphinDetailsView::zoomIn()
     if (isZoomInPossible()) {
         DolphinDetailsViewSettings* settings = DolphinSettings::instance().detailsView();
         switch (settings->iconSize()) {
-            case KIcon::SizeSmall:  settings->setIconSize(KIcon::SizeMedium); break;
-            case KIcon::SizeMedium: settings->setIconSize(KIcon::SizeLarge); break;
+            case TDEIcon::SizeSmall:  settings->setIconSize(TDEIcon::SizeMedium); break;
+            case TDEIcon::SizeMedium: settings->setIconSize(TDEIcon::SizeLarge); break;
             default: assert(false); break;
         }
         ItemEffectsManager::zoomIn();
@@ -192,8 +192,8 @@ void DolphinDetailsView::zoomOut()
     if (isZoomOutPossible()) {
         DolphinDetailsViewSettings* settings = DolphinSettings::instance().detailsView();
         switch (settings->iconSize()) {
-            case KIcon::SizeLarge:  settings->setIconSize(KIcon::SizeMedium); break;
-            case KIcon::SizeMedium: settings->setIconSize(KIcon::SizeSmall); break;
+            case TDEIcon::SizeLarge:  settings->setIconSize(TDEIcon::SizeMedium); break;
+            case TDEIcon::SizeMedium: settings->setIconSize(TDEIcon::SizeSmall); break;
             default: assert(false); break;
         }
         ItemEffectsManager::zoomOut();
@@ -203,13 +203,13 @@ void DolphinDetailsView::zoomOut()
 bool DolphinDetailsView::isZoomInPossible() const
 {
     DolphinDetailsViewSettings* settings = DolphinSettings::instance().detailsView();
-    return settings->iconSize() < KIcon::SizeLarge;
+    return settings->iconSize() < TDEIcon::SizeLarge;
 }
 
 bool DolphinDetailsView::isZoomOutPossible() const
 {
     DolphinDetailsViewSettings* settings = DolphinSettings::instance().detailsView();
-    return settings->iconSize() > KIcon::SizeSmall;
+    return settings->iconSize() > TDEIcon::SizeSmall;
 }
 
 void DolphinDetailsView::resizeContents(int width, int height)
@@ -379,7 +379,7 @@ void DolphinDetailsView::contentsMousePressEvent(TQMouseEvent* event)
         KFileDetailView::contentsMousePressEvent(event);
     }
     else if (event->button() == Qt::LeftButton) {
-        const ButtonState keyboardState = KApplication::keyboardMouseState();
+        const ButtonState keyboardState = TDEApplication::keyboardMouseState();
         const bool isSelectionActive = (keyboardState & ShiftButton) ||
                                        (keyboardState & ControlButton);
         if (!isSelectionActive) {
@@ -683,7 +683,7 @@ DolphinDetailsView::DolphinListViewItem::DolphinListViewItem(TQListView* parent,
         setText(SizeColumn, " - ");
     }
     else {
-        TQString sizeText(KIO::convertSize(fileItem->size()));
+        TQString sizeText(TDEIO::convertSize(fileItem->size()));
         sizeText.append(" ");
         setText(SizeColumn, sizeText);
     }
@@ -750,7 +750,7 @@ void DolphinDetailsView::DolphinListViewItem::paintCell(TQPainter* painter,
 
     if (column < listView()->columns() - 1) {
         // draw a separator between columns
-        painter->setPen(KGlobalSettings::buttonBackground());
+        painter->setPen(TDEGlobalSettings::buttonBackground());
         painter->drawLine(cellWidth - 1, 0, cellWidth - 1, height() - 1);
     }
 }
